Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(544)

Unified Diff: webrtc/p2p/base/candidate.h

Issue 1976683003: Update the type and cost of existing networks if its type is found later by network monitor (Closed) Base URL: https://chromium.googlesource.com/external/webrtc@master
Patch Set: Get network type from name matching only on IOS or Android. Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/p2p/base/candidate.h
diff --git a/webrtc/p2p/base/candidate.h b/webrtc/p2p/base/candidate.h
index ec758d2aa51c2659fdc15dd64cf60631fb566bf9..9a88b5f6d558adc850f889efb18a9a6d321ddf8b 100644
--- a/webrtc/p2p/base/candidate.h
+++ b/webrtc/p2p/base/candidate.h
@@ -27,8 +27,6 @@
namespace cricket {
-const uint16_t kMaxNetworkCost = 999;
-
// Candidate for ICE based connection discovery.
class Candidate {
@@ -148,9 +146,9 @@ class Candidate {
// |network_cost| measures the cost/penalty of using this candidate. A network
// cost of 0 indicates this candidate can be used freely. A value of
// |kMaxNetworkCost| indicates it should be used only as the last resort.
void set_network_cost(uint16_t network_cost) {
- ASSERT(network_cost <= kMaxNetworkCost);
+ ASSERT(network_cost <= rtc::kMaxNetworkCost);
network_cost_ = network_cost;
}
uint16_t network_cost() const { return network_cost_; }
@@ -148,9 +146,9 @@ class Candidate {
// |network_cost| measures the cost/penalty of using this candidate. A network
// cost of 0 indicates this candidate can be used freely. A value of
- // |kMaxNetworkCost| indicates it should be used only as the last resort.
+ // rtc::kMaxNetworkCost indicates it should be used only as the last resort.
void set_network_cost(uint16_t network_cost) {

Powered by Google App Engine
This is Rietveld 408576698